==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/BackupLongTermRetentionPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A long term retention policy.
 * Azure REST API version: 2017-03-01-preview.
 * ## Example Usage
 * ### Create or update the long term retention policy for the database.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var backupLongTermRetentionPolicy = new AzureNative.Sql.BackupLongTermRetentionPolicy("backupLongTermRetentionPolicy", new()
 *     {
 *         DatabaseName = "testDatabase",
 *         MonthlyRetention = "P1Y",
 *         PolicyName = "default",
 *         ResourceGroupName = "resourceGroup",
 *         ServerName = "testserver",
 *         WeekOfYear = 5,
 *         WeeklyRetention = "P1M",
 *         YearlyRetention = "P5Y",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewBackupLongTermRetentionPolicy(ctx, "backupLongTermRetentionPolicy", &sql.BackupLongTermRetentionPolicyArgs{
 * 			DatabaseName:      pulumi.String("testDatabase"),
 * 			MonthlyRetention:  pulumi.String("P1Y"),
 * 			PolicyName:        pulumi.String("default"),
 * 			ResourceGroupName: pulumi.String("resourceGroup"),
 * 			ServerName:        pulumi.String("testserver"),
 * 			WeekOfYear:        pulumi.Int(5),
 * 			WeeklyRetention:   pulumi.String("P1M"),
 * 			YearlyRetention:   pulumi.String("P5Y"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.BackupLongTermRetentionPolicy;
 * import com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var backupLongTermRetentionPolicy = new BackupLongTermRetentionPolicy("backupLongTermRetentionPolicy", BackupLongTermRetentionPolicyArgs.builder()
 *             .databaseName("testDatabase")
 *             .monthlyRetention("P1Y")
 *             .policyName("default")
 *             .resourceGroupName("resourceGroup")
 *             .serverName("testserver")
 *             .weekOfYear(5)
 *             .weeklyRetention("P1M")
 *             .yearlyRetention("P5Y")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:BackupLongTermRetentionPolicy default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/databases/{databaseName}/backupLongTermRetentionPolicies/{policyName}
 * ```
 * @property databaseName The name of the database.
 * @property monthlyRetention The monthly retention policy for an LTR backup in an ISO 8601 format.
 * @property policyName The policy name. Should always be Default.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serverName The name of the server.
 * @property weekOfYear The week of year to take the yearly backup in an ISO 8601 format.
 * @property weeklyRetention The weekly retention policy for an LTR backup in an ISO 8601 format.
 * @property yearlyRetention The yearly retention policy for an LTR backup in an ISO 8601 format.
 */
public data class BackupLongTermRetentionPolicyArgs(
    public val databaseName: Output<String>? = null,
    public val monthlyRetention: Output<String>? = null,
    public val policyName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serverName: Output<String>? = null,
    public val weekOfYear: Output<Int>? = null,
    public val weeklyRetention: Output<String>? = null,
    public val yearlyRetention: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs =
        com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs.builder()
            .databaseName(databaseName?.applyValue({ args0 -> args0 }))
            .monthlyRetention(monthlyRetention?.applyValue({ args0 -> args0 }))
            .policyName(policyName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 }))
            .weekOfYear(weekOfYear?.applyValue({ args0 -> args0 }))
            .weeklyRetention(weeklyRetention?.applyValue({ args0 -> args0 }))
            .yearlyRetention(yearlyRetention?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BackupLongTermRetentionPolicyArgs].
 */
@PulumiTagMarker
public class BackupLongTermRetentionPolicyArgsBuilder internal constructor() {
    private var databaseName: Output<String>? = null

    private var monthlyRetention: Output<String>? = null

    private var policyName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var serverName: Output<String>? = null

    private var weekOfYear: Output<Int>? = null

    private var weeklyRetention: Output<String>? = null

    private var yearlyRetention: Output<String>? = null

    /**
     * @param value The name of the database.
     */
    @JvmName("mjixaiawydpvnobs")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value The monthly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("xchqjvipawhmkycj")
    public suspend fun monthlyRetention(`value`: Output<String>) {
        this.monthlyRetention = value
    }

    /**
     * @param value The policy name. Should always be Default.
     */
    @JvmName("druqpanrugkuimfm")
    public suspend fun policyName(`value`: Output<String>) {
        this.policyName = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("sodnsrqltxhjevvw")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("ufvuoulpwfcrwvtd")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The week of year to take the yearly backup in an ISO 8601 format.
     */
    @JvmName("nrujsmquwerkdpdf")
    public suspend fun weekOfYear(`value`: Output<Int>) {
        this.weekOfYear = value
    }

    /**
     * @param value The weekly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("xlquxwbxlojflspy")
    public suspend fun weeklyRetention(`value`: Output<String>) {
        this.weeklyRetention = value
    }

    /**
     * @param value The yearly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("htgjocchdhimitgn")
    public suspend fun yearlyRetention(`value`: Output<String>) {
        this.yearlyRetention = value
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("ltsbrjnvesqblsra")
    public suspend fun databaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value The monthly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("taromjtlwrmlusox")
    public suspend fun monthlyRetention(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlyRetention = mapped
    }

    /**
     * @param value The policy name. Should always be Default.
     */
    @JvmName("ggsvmyeaqosnrgdc")
    public suspend fun policyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("lgrljkknriiqkjcu")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("pkaydryabbgdacew")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    /**
     * @param value The week of year to take the yearly backup in an ISO 8601 format.
     */
    @JvmName("phrjsgqqxjmomvca")
    public suspend fun weekOfYear(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekOfYear = mapped
    }

    /**
     * @param value The weekly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("nstvlihpwanwxqlr")
    public suspend fun weeklyRetention(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weeklyRetention = mapped
    }

    /**
     * @param value The yearly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("mramjciulbbplodc")
    public suspend fun yearlyRetention(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.yearlyRetention = mapped
    }

    internal fun build(): BackupLongTermRetentionPolicyArgs = BackupLongTermRetentionPolicyArgs(
        databaseName = databaseName,
        monthlyRetention = monthlyRetention,
        policyName = policyName,
        resourceGroupName = resourceGroupName,
        serverName = serverName,
        weekOfYear = weekOfYear,
        weeklyRetention = weeklyRetention,
        yearlyRetention = yearlyRetention,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/BackupLongTermRetentionPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A long term retention policy.
 * Azure REST API version: 2017-03-01-preview.
 * ## Example Usage
 * ### Create or update the long term retention policy for the database.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var backupLongTermRetentionPolicy = new AzureNative.Sql.BackupLongTermRetentionPolicy("backupLongTermRetentionPolicy", new()
 *     {
 *         DatabaseName = "testDatabase",
 *         MonthlyRetention = "P1Y",
 *         PolicyName = "default",
 *         ResourceGroupName = "resourceGroup",
 *         ServerName = "testserver",
 *         WeekOfYear = 5,
 *         WeeklyRetention = "P1M",
 *         YearlyRetention = "P5Y",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewBackupLongTermRetentionPolicy(ctx, "backupLongTermRetentionPolicy", &sql.BackupLongTermRetentionPolicyArgs{
 * 			DatabaseName:      pulumi.String("testDatabase"),
 * 			MonthlyRetention:  pulumi.String("P1Y"),
 * 			PolicyName:        pulumi.String("default"),
 * 			ResourceGroupName: pulumi.String("resourceGroup"),
 * 			ServerName:        pulumi.String("testserver"),
 * 			WeekOfYear:        pulumi.Int(5),
 * 			WeeklyRetention:   pulumi.String("P1M"),
 * 			YearlyRetention:   pulumi.String("P5Y"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.BackupLongTermRetentionPolicy;
 * import com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var backupLongTermRetentionPolicy = new BackupLongTermRetentionPolicy("backupLongTermRetentionPolicy", BackupLongTermRetentionPolicyArgs.builder()
 *             .databaseName("testDatabase")
 *             .monthlyRetention("P1Y")
 *             .policyName("default")
 *             .resourceGroupName("resourceGroup")
 *             .serverName("testserver")
 *             .weekOfYear(5)
 *             .weeklyRetention("P1M")
 *             .yearlyRetention("P5Y")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:BackupLongTermRetentionPolicy default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/databases/{databaseName}/backupLongTermRetentionPolicies/{policyName}
 * ```
 * @property databaseName The name of the database.
 * @property monthlyRetention The monthly retention policy for an LTR backup in an ISO 8601 format.
 * @property policyName The policy name. Should always be Default.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serverName The name of the server.
 * @property weekOfYear The week of year to take the yearly backup in an ISO 8601 format.
 * @property weeklyRetention The weekly retention policy for an LTR backup in an ISO 8601 format.
 * @property yearlyRetention The yearly retention policy for an LTR backup in an ISO 8601 format.
 */
public data class BackupLongTermRetentionPolicyArgs(
    public val databaseName: Output<String>? = null,
    public val monthlyRetention: Output<String>? = null,
    public val policyName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serverName: Output<String>? = null,
    public val weekOfYear: Output<Int>? = null,
    public val weeklyRetention: Output<String>? = null,
    public val yearlyRetention: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs =
        com.pulumi.azurenative.sql.BackupLongTermRetentionPolicyArgs.builder()
            .databaseName(databaseName?.applyValue({ args0 -> args0 }))
            .monthlyRetention(monthlyRetention?.applyValue({ args0 -> args0 }))
            .policyName(policyName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 }))
            .weekOfYear(weekOfYear?.applyValue({ args0 -> args0 }))
            .weeklyRetention(weeklyRetention?.applyValue({ args0 -> args0 }))
            .yearlyRetention(yearlyRetention?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BackupLongTermRetentionPolicyArgs].
 */
@PulumiTagMarker
public class BackupLongTermRetentionPolicyArgsBuilder internal constructor() {
    private var databaseName: Output<String>? = null

    private var monthlyRetention: Output<String>? = null

    private var policyName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var serverName: Output<String>? = null

    private var weekOfYear: Output<Int>? = null

    private var weeklyRetention: Output<String>? = null

    private var yearlyRetention: Output<String>? = null

    /**
     * @param value The name of the database.
     */
    @JvmName("crnelrjxjxicxjjk")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value The monthly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("pqlgqrvateeuohsu")
    public suspend fun monthlyRetention(`value`: Output<String>) {
        this.monthlyRetention = value
    }

    /**
     * @param value The policy name. Should always be Default.
     */
    @JvmName("gsljkxolbxknonjw")
    public suspend fun policyName(`value`: Output<String>) {
        this.policyName = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("rkaqgysghhsrwdrm")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("xiseyohtdysridmk")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The week of year to take the yearly backup in an ISO 8601 format.
     */
    @JvmName("keunqpwxxccedgfh")
    public suspend fun weekOfYear(`value`: Output<Int>) {
        this.weekOfYear = value
    }

    /**
     * @param value The weekly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("bmsosxhsgstkdjiw")
    public suspend fun weeklyRetention(`value`: Output<String>) {
        this.weeklyRetention = value
    }

    /**
     * @param value The yearly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("djygtdlkeummmvts")
    public suspend fun yearlyRetention(`value`: Output<String>) {
        this.yearlyRetention = value
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("wavyifcumdjfxgqc")
    public suspend fun databaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value The monthly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("gclkbbxqsvautrlw")
    public suspend fun monthlyRetention(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlyRetention = mapped
    }

    /**
     * @param value The policy name. Should always be Default.
     */
    @JvmName("aueqphomwepssewb")
    public suspend fun policyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("aehlcayoddrdpiov")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("rrhkfdhdiwgtrtre")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    /**
     * @param value The week of year to take the yearly backup in an ISO 8601 format.
     */
    @JvmName("hgsyijnqxlfeirqy")
    public suspend fun weekOfYear(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekOfYear = mapped
    }

    /**
     * @param value The weekly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("uktifayocvsbaerh")
    public suspend fun weeklyRetention(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weeklyRetention = mapped
    }

    /**
     * @param value The yearly retention policy for an LTR backup in an ISO 8601 format.
     */
    @JvmName("qthkuqeusrlmxyxe")
    public suspend fun yearlyRetention(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.yearlyRetention = mapped
    }

    internal fun build(): BackupLongTermRetentionPolicyArgs = BackupLongTermRetentionPolicyArgs(
        databaseName = databaseName,
        monthlyRetention = monthlyRetention,
        policyName = policyName,
        resourceGroupName = resourceGroupName,
        serverName = serverName,
        weekOfYear = weekOfYear,
        weeklyRetention = weeklyRetention,
        yearlyRetention = yearlyRetention,
    )
}
